@@ -1,8 +1,7 @@
 __all__ = ["start_controller", "stop_controller", "message_for_action"]
 
-import constants.list_key
-import helper.colour as colour
-import helper.thread
+from .. import helper
+from ..helper import colour
 
 def start_controller(thread: str) -> None:
     if helper.thread.is_none(thread):
@@ -15,8 +14,8 @@ def stop_controller(timer: object, thread: str) -> None:
         print(f"{colour.yellow()}Timer is not running. Use .start() to start it.{colour.reset()}")
     else:
         print(f"{colour.yellow()}Timer for thread {thread} is not running. Use .start({thread = }) to start it.{colour.reset()}")
-    if len(timer.thread_list) > 0:
-        open_threads = [entry.get(constants.list_key.thread()) for entry in timer.thread_list]
+    if len(timer.threads) > 0:
+        open_threads = [thread_item.name for thread_item in timer.threads]
         print(f"Or maybe you aren't stopping the right thread? Currently open threads: {', '.join(open_threads)}")
 
 def message_for_action(action: str, thread: str = None) -> None:
